@@ -19,7 +19,10 @@ class TomlLoader(Loader):
         null_caster,
     ]
 
-    def loading(self, conf: Any) -> Diot:
+    def loading(self, conf: Any, ignore_nonexist: bool) -> Diot:
         """Load the configuration from a toml file"""
+        if not self._exists(conf, ignore_nonexist):
+            return Diot()
+
         with open(conf) as f:
             return Diot(rtoml.load(f))
